summaryrefslogtreecommitdiffstats
path: root/examples/cpu-hello-world/main.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'examples/cpu-hello-world/main.cpp')
-rw-r--r--examples/cpu-hello-world/main.cpp4
1 files changed, 2 insertions, 2 deletions
diff --git a/examples/cpu-hello-world/main.cpp b/examples/cpu-hello-world/main.cpp
index 898347b47..ee919a713 100644
--- a/examples/cpu-hello-world/main.cpp
+++ b/examples/cpu-hello-world/main.cpp
@@ -72,8 +72,8 @@ static SlangResult _innerMain(int argc, char** argv)
// is for the prelude code to be an *absolute* path to the 'slang-cpp-prelude.h' - which means
// this will work wherever the generated code is, and allows accessing other files via relative paths.
//
- // Look at the source to TestToolUtil::setSessionDefaultPrelude to see what's involed.
- TestToolUtil::setSessionDefaultPrelude(argv[0], slangSession);
+ // Look at the source to TestToolUtil::setSessionDefaultPreludeFromExePath to see what's involed.
+ TestToolUtil::setSessionDefaultPreludeFromExePath(argv[0], slangSession);
// A compile request represents a single invocation of the compiler,
// to process some inputs and produce outputs (or errors).